## -*- coding: utf-8; -*-
<%inherit file="/batch/view.mako" />

<%def name="extra_javascript()">
  ${parent.extra_javascript()}
  % if master.has_perm('edit_row'):
      ${h.javascript_link(request.static_url('tailbone:static/js/numeric.js'))}
      <script type="text/javascript">

        % if not batch.executed:
        // keep track of which cost value is currently being edited
        var editing = null;

        function start_editing(td) {
            var value = 0;
            var text = td.text().replace(/^\s+|\s+$/g, '');
            if (text) {
                td.data('previous-value', text);
                td.text('');
                value = parseFloat(text.replace('$', ''));
            }
            var input = $('<input type="text" />');
            td.append(input);
            input.val(value.toString()).select().focus();
            editing = td;
        }

        function start_editing_next() {
            var tr = editing.parents('tr:first');
            var next = tr.next('tr:first');
            if (next.length) {
                start_editing(next.find('td.invoice_unit_cost'));
            }
        }

        function cancel_edit() {
            var input = editing.find('input');
            input.blur();
            input.remove();
            var value = editing.data('previous-value');
            if (value) {
                editing.text(value);
            }
            editing = null;
        }

        % endif

        $(function() {

            % if not batch.executed:
            $('.grid-wrapper').on('click', '.grid td.invoice_unit_cost', function() {
                if (editing) {
                    editing.find('input').focus();
                    return
                }
                var td = $(this);
                start_editing(td);
            });

            $('.grid-wrapper').on('keyup', '.grid td.invoice_unit_cost input', function(event) {
                var input = $(this);

                // let numeric keys modify input value
                if (! key_modifies(event)) {

                    // when user presses Enter while editing cost value, submit
                    // value to server for immediate persistence
                    if (event.which == 13) {
                        $('.grid-wrapper').mask("Updating cost...");
                        var url = '${url('receiving.update_row_cost', uuid=batch.uuid)}';
                        var td = input.parents('td:first');
                        var tr = td.parents('tr:first');
                        var data = {
                            '_csrf': $('[name="_csrf"]').val(),
                            'row_uuid': tr.data('uuid'),
                            'invoice_unit_cost': input.val()
                        };
                        $.post(url, data, function(data) {
                            if (data.error) {
                                alert(data.error);
                            } else {
                                var total = null;

                                // update unit cost for row
                                td.text(data.row.invoice_unit_cost);

                                // update invoice total for row
                                total = tr.find('td.invoice_total_calculated');
                                total.text('$' + data.row.invoice_total_calculated);

                                // update invoice total for batch
                                total = $('.form .field-wrapper.invoice_total_calculated .field');
                                total.text('$' + data.batch.invoice_total_calculated);

                                // mark cost as confirmed
                                if (data.row.invoice_cost_confirmed) {
                                    tr.addClass('invoice_cost_confirmed');
                                }

                                input.blur();
                                input.remove();
                                start_editing_next();
                            }
                            $('.grid-wrapper').unmask();
                        });

                    // When user presses Escape while editing totals, cancel the edit.
                    } else if (event.which == 27) {
                        cancel_edit();

                    // Most other keys at this point should be unwanted...
                    } else if (! key_allowed(event)) {
                        return false;
                    }
                }
            });
            % endif

            $('.grid-wrapper').on('click', '.grid .actions a.transform', function() {

                var form = $('form[name="transform-unit-form"]');
                var row_uuid = $(this).parents('tr:first').data('uuid');
                form.find('[name="row_uuid"]').val(row_uuid);

                $.get(form.attr('action'), {row_uuid: row_uuid}, function(data) {

                    if (typeof(data) == 'object') {
                        alert(data.error);

                    } else {
                        $('#transform-unit-dialog').html(data);
                        $('#transform-unit-dialog').dialog({
                            title: "Transform Pack to Unit Item",
                            width: 800,
                            height: 450,
                            modal: true,
                            buttons: [
                                {
                                    text: "Transform",
                                    click: function(event) {
                                        disable_button(dialog_button(event));
                                        form.submit();
                                    }
                                },
                                {
                                    text: "Cancel",
                                    click: function() {
                                        $(this).dialog('close');
                                    }
                                }
                            ]
                        });
                    }
                });

                return false;
            });

        });

      </script>
  % endif
</%def>

<%def name="extra_styles()">
  ${parent.extra_styles()}
  % if not batch.executed and master.has_perm('edit_row'):
      <style type="text/css">
        .grid tr:not(.header) td.invoice_unit_cost {
          cursor: pointer;
          background-color: #fcc;
        }
        .grid tr.invoice_cost_confirmed:not(.header) td.invoice_unit_cost {
          background-color: #cfc;
        }
        .grid td.invoice_unit_cost input {
          width: 4rem;
        }
      </style>
  % endif
</%def>

<%def name="object_helpers()">
  ${parent.object_helpers()}
  % if not request.rattail_config.production() and not batch.executed and not batch.complete and request.has_perm('admin') and batch.is_truck_dump_parent() and batch.truck_dump_children_first:
      <div class="object-helper">
        <h3>Development Tools</h3>
        <div class="object-helper-content">
          ${h.form(url('{}.auto_receive'.format(route_prefix), uuid=batch.uuid), class_='autodisable')}
          ${h.csrf_token(request)}
          ${h.submit('submit', "Auto-Receive All Items")}
          ${h.end_form()}
        </div>
      </div>
  % endif
</%def>


${parent.body()}

% if master.allow_truck_dump and request.has_perm('{}.edit_row'.format(permission_prefix)):
    ${h.form(url('{}.transform_unit_row'.format(route_prefix), uuid=batch.uuid), name='transform-unit-form')}
    ${h.csrf_token(request)}
    ${h.hidden('row_uuid')}
    ${h.end_form()}

    <div id="transform-unit-dialog" style="display: none;">
      <p>hello world</p>
    </div>
% endif
